/**
 * 获取指定的路径信息
 * @param  {string} fileOrDirPath   文件或目录路径
 * @return {object} 文件信息，如：{type:'dir'|'file'|undefined,}
 */
 const pathInfo = (fileOrDirPath, debug) => {
    const fs = require('fs'),
        path = require('path')
        result = {
            type: undefined,                                    // 类型 'dir'|'file'
            extension: undefined,                               // 扩展名 'undefined|空|xxx'
            name: undefined,                                    // 文件名 不包含扩展名部分
            isExist: undefined                                  // 是否存在
        };

    if(!fileOrDirPath){
        return result;
    };
    try {
        let stat = fs.statSync(fileOrDirPath);

        //如果路径是一个目录，则返回目录信息
        if (stat.isDirectory()) {
            result.type = 'dir';
            result.isExist = true;

            let backPath = path.resolve(fileOrDirPath, '../'), // 跳到路径上一级目录
                dirName = fileOrDirPath.replace(backPath, ''), // 去除上级目录路径
                re = /[/]|[\\]/g;

            result.name = dirName.replace(re, '');             // 去除处理路径后的/\符号
            return result;
        };

        if (stat.isFile()) {
            result.type = 'file';
            result.isExist = true;
        };

        if (stat.isSymbolicLink()){
            result.type = 'symlink';
            result.isExist = true;
        };
    } catch (error) {
        if (debug) {
            console.log(`${fileOrDirPath} 文件不存在, ${error}`);
        };
    };
    result.extension = (() => {
        let extName = path.extname(fileOrDirPath);
        return extName[0] === '.' ? extName.slice(1) : extName;
    })();
    result.name = path.basename(fileOrDirPath, `.${result.extension}`);
    return result;
};

module.exports = pathInfo;

